@@ -149,9 +149,12 @@ def attachSettings(settingsDict, enablePaypal=False):
         update(settingsDict, ADD_STATICFILES_FINDERS)
 
     #=========================================================================
-
+    if 'OSCAR_DEFAULT_CURRENCY' not in settingsDict:
+        settingsDict['OSCAR_DEFAULT_CURRENCY'] = 'USD'
     #=========================================================================
     # Oscar default settings 
+    # __import__ 模組的用法與官方文件有落差，可能是使用時帶入參數有誤，先以目前的寫法帶過
+    # see #2784
     addOscarDefaultsPackages = {}
     oscarDefaultsPackages = __import__(
             'oscar.defaults', globals(), locals(), [], -1
@@ -196,6 +199,7 @@ def attachSettings(settingsDict, enablePaypal=False):
             settingsDict['OSCAR_DASHBOARD_NAVIGATION'] = ADDING_OSCAR_DASHBOARD_NAVIGATION
     #=========================================================================
 
+
 def attachShopURLs(settings, urlpatterns):
     """
     Attach shop related urlpatterns.
@@ -230,4 +234,5 @@ def attachPaypalURLs(settings, urlpatterns):
         (r'^checkout/payment-details/', include('paypal.express.urls')),
         (r'^shop/dashboard/paypal/express/', include(application.urls)),
 
-    )
\ No newline at end of file
+    )
+
